@@ -6,5 +6,6 @@
 # @Filename: __init__.py
 # @License: BSD 3-clause (http://www.opensource.org/licenses/BSD-3-Clause)
 
-from .actor import ArchonActor, ExposeData
+from .actor import ArchonActor, ArchonCommandType
 from .commands import parser
+from .delegate import ExposeData, ExposureDelegate
