@@ -10,14 +10,17 @@ from __future__ import annotations
 
 import asyncio
 import os
+import pathlib
 import warnings
 from contextlib import suppress
-from dataclasses import dataclass, field
 
-from typing import Any, Dict
+from typing import ClassVar, Dict, Type
 
-import astropy.time
-from clu.actor import AMQPActor
+import click
+from clu import Command
+from clu.actor import AMQPActor, BaseActor
+
+from sdsstools.configuration import Configuration
 
 from archon import __version__
 from archon.controller.command import ArchonCommand
@@ -25,15 +28,17 @@ from archon.controller.controller import ArchonController
 from archon.exceptions import ArchonUserWarning
 
 from .commands import parser as archon_command_parser
-
-__all__ = ["ArchonActor"]
+from .delegate import ExposureDelegate
 
 
-class ArchonActor(AMQPActor):
-    """Archon controller actor.
+__all__ = ["ArchonBaseActor", "ArchonActor"]
 
-    In addition to the normal arguments and keyword parameters for
-    `~clu.actor.AMQPActor`, the class accepts the following parameters.
+
+class ArchonBaseActor(BaseActor):
+    """Archon controller base actor.
+
+    This class is intended to be subclassed with a specific actor class (normally
+    ``AMQPActor`` or ``LegacyActor``).
 
     Parameters
     ----------
@@ -41,7 +46,11 @@ class ArchonActor(AMQPActor):
         The list of `.ArchonController` instances to manage.
     """
 
-    parser = archon_command_parser
+    parser: ClassVar[click.Group] = archon_command_parser
+    is_legacy: bool = False
+
+    BASE_CONFIG: ClassVar[str | Dict | None] = None
+    DELEGATE_CLASS: ClassVar[Type[ExposureDelegate]] = ExposureDelegate
 
     def __init__(
         self,
@@ -57,7 +66,7 @@ class ArchonActor(AMQPActor):
         if "schema" not in kwargs:
             kwargs["schema"] = os.path.join(
                 os.path.dirname(__file__),
-                "../etc/archon.json",
+                "../etc/schema.json",
             )
 
         super().__init__(*args, **kwargs)
@@ -65,12 +74,22 @@ class ArchonActor(AMQPActor):
         self.observatory = os.environ.get("OBSERVATORY", "LCO")
         self.version = __version__
 
-        self.expose_data: ExposeData | None = None
+        # Issue status and system on a loop.
+        # self.timed_commands.add_command("status", delay=60)  # type: ignore
+        # self.timed_commands.add_command("system", delay=60)  # type: ignore
+
+        self.expose_delegate = self.DELEGATE_CLASS(self)
+
+        self._fetch_log_jobs = []
+        self._status_jobs = []
+
+        self.config_file_path: str | None = None
 
     async def start(self):
         """Start the actor and connect the controllers."""
 
         connect_timeout = self.config["timeouts"]["controller_connect"]
+        connect_timeout = 10
 
         for controller in self.controllers.values():
             try:
@@ -80,6 +99,12 @@ class ArchonActor(AMQPActor):
                     f"Timeout out connecting to {controller.name!r}.",
                     ArchonUserWarning,
                 )
+            except Exception as err:
+                warnings.warn(
+                    f"Failed connecting to controller {controller.name} at "
+                    f"{controller.host}: {err}",
+                    ArchonUserWarning,
+                )
 
         await super().start()
 
@@ -98,38 +123,67 @@ class ArchonActor(AMQPActor):
             for task in self._fetch_log_jobs:
                 task.cancel()
                 await task
-        return super().stop()
+
+        for controller in self.controllers.values():
+            await controller.stop()
+
+        return await super().stop()
 
     @classmethod
     def from_config(cls, config, *args, **kwargs):
         """Creates an actor from a configuration file."""
-        instance = super(ArchonActor, cls).from_config(config, *args, **kwargs)
-        assert isinstance(instance, ArchonActor)
+
+        if config is None:
+            if cls.BASE_CONFIG is None:
+                raise RuntimeError("The class does not have a base configuration.")
+            config = cls.BASE_CONFIG
+
+        instance = super(ArchonBaseActor, cls).from_config(config, *args, **kwargs)
+
+        if isinstance(config, (str, pathlib.Path)):
+            instance.config_file_path = str(config)
+        elif isinstance(config, Configuration):
+            instance.config_file_path = str(
+                config._BASE_CONFIG_FILE
+                if config._BASE_CONFIG_FILE
+                else config.CONFIG_FILE
+            )
+
+        assert isinstance(instance, ArchonBaseActor)
         assert isinstance(instance.config, dict)
+
+        enabled_controllers = instance.config.get("enabled_controllers", None)
+
         if "controllers" in instance.config:
             controllers = (
                 ArchonController(
+                    ctrname,
                     ctr["host"],
                     ctr["port"],
-                    name=ctrname,
                 )
                 for (ctrname, ctr) in instance.config["controllers"].items()
+                if enabled_controllers is not None and ctrname in enabled_controllers
             )
             instance.controllers = {c.name: c for c in controllers}
             instance.parser_args = [instance.controllers]  # Need to refresh this
+
         return instance
 
-    async def _fetch_log(self, controller: ArchonController):
+    async def _fetch_log(self, controller: ArchonController):  # pragma: no cover
         """Fetches the log and outputs new messages.
 
         This is not implemented as a timed command because we don't want a new command
         popping up and running every second. We write to all users only when there's
         a new log.
         """
+
         while True:
+            if not controller.is_connected():
+                await asyncio.sleep(1)
+                continue
             cmd: ArchonCommand = await controller.send_command("FETCHLOG")
             if cmd.succeeded() and len(cmd.replies) == 1:
-                if str(cmd.replies[0].reply) != "(null)":
+                if str(cmd.replies[0].reply) not in ["(null)", ""]:
                     self.write(
                         log=dict(
                             controller=controller.name,
@@ -141,6 +195,7 @@ class ArchonActor(AMQPActor):
 
     async def _report_status(self, controller: ArchonController):
         """Reports the status of the controller."""
+
         async for status in controller.yield_status():
             self.write(
                 status=dict(
@@ -151,15 +206,10 @@ class ArchonActor(AMQPActor):
             )
 
 
-@dataclass
-class ExposeData:
-    """Data about the ongoing exposure."""
+class ArchonActor(ArchonBaseActor, AMQPActor):
+    """Archon actor based on the AMQP protocol."""
 
-    exposure_time: float
-    flavour: str
-    controllers: list[ArchonController]
-    start_time: astropy.time.Time = astropy.time.Time.now()
-    end_time: astropy.time.Time | None = None
-    mjd: int = 0
-    exposure_no: int = 0
-    header: Dict[str, Any] = field(default_factory=dict)
+    pass
+
+
+ArchonCommandType = Command[ArchonActor]
