@@ -11,33 +11,35 @@ from __future__ import annotations
 import asyncio
 import fcntl
 import functools
+import json
+import pathlib
 from contextlib import contextmanager
 from os import PathLike
 
-from typing import IO, Any, Generator, Optional, Tuple
+from typing import IO, Any, Generator
 
-import astropy.time
 import click
 from clu.command import BaseCommand, Command
 
-from archon import config
 from archon.controller.controller import ArchonController
 
+
 __all__ = [
     "parallel_controllers",
     "error_controller",
     "check_controller",
     "open_with_lock",
-    "read_govee",
+    "controller",
+    "get_schema",
 ]
 
 
-controller_list = click.option(
+controller = click.option(
     "-c",
     "--controller",
-    "controller_list",
     type=str,
-    help="Controllers to which to talk. Defaults to all available.",
+    nargs=1,
+    help="Controller to command",
 )
 
 
@@ -70,25 +72,24 @@ def parallel_controllers(check=True):
 
     def decorator(f):
         @functools.wraps(f)
-        @controller_list
+        @controller
         async def wrapper(
             command: BaseCommand,
             controllers: dict[str, ArchonController],
-            controller_list: Optional[str] = None,
+            controller: str | None,
             **kwargs,
         ):
-            if controller_list:
-                controller_keys = list(
-                    map(lambda x: x.strip(), controller_list.split(","))
-                )
-            else:
-                controller_keys = list(controllers.keys())
 
-            if len(controller_keys) == 0:
+            if not controller:
+                controller_list = tuple(controllers.keys())
+            else:
+                controller_list = (controller,)
+
+            if len(controller_list) == 0:
                 return command.fail("No controllers are available.")
 
             tasks: list[asyncio.Task] = []
-            for k in controller_keys:
+            for k in controller_list:
                 if check:
                     if k not in controllers:
                         return command.fail(f"Invalid controller {k!r}.")
@@ -100,7 +101,7 @@ def parallel_controllers(check=True):
                 tasks, return_when=asyncio.FIRST_EXCEPTION
             )
 
-            if len(pending) > 0:
+            if len(pending) > 0:  # pragma: no cover
                 for p in pending:
                     p.cancel()
                 return command.fail("Some tasks raised exceptions.")
@@ -117,12 +118,14 @@ def parallel_controllers(check=True):
 
 def error_controller(command: Command, controller: ArchonController, message: str):
     """Issues a ``error_controller`` message."""
+
     command.error(
-        text={
+        error={
             "controller": controller.name,
-            "text": message,
+            "error": message,
         }
     )
+
     return False
 
 
@@ -132,6 +135,7 @@ def check_controller(command: Command, controller: ArchonController) -> bool:
     Outputs error messages if a problem is found. Return `False` if the controller
     is not in a valid state.
     """
+
     if not controller.is_connected():
         error_controller(command, controller, "Controller not connected.")
         return False
@@ -142,7 +146,7 @@ def check_controller(command: Command, controller: ArchonController) -> bool:
 @contextmanager
 def open_with_lock(
     filename: PathLike, mode: str = "r"
-) -> Generator[IO[Any], None, None]:
+) -> Generator[IO[Any], None, None]:  # pragma: no cover
     """Opens a file and adds an advisory lock on it.
 
     Parameters
@@ -157,6 +161,7 @@ def open_with_lock(
     BlockingIOError
         If the file is already locked.
     """
+
     # Open the file in read-only mode first to see if it's already locked.
     fd = open(filename, "r")
     fcntl.flock(fd, fcntl.LOCK_EX | fcntl.LOCK_NB)
@@ -170,32 +175,9 @@ def open_with_lock(
         fcntl.flock(fd, fcntl.LOCK_UN)
 
 
-async def read_govee() -> Tuple[float, float]:
-    """Connects to the H5179 device and gets the lab temperature and humidity."""
+def get_schema():
+    """Returns the default JSONschema for Archon actors."""
 
-    h5179 = config["sensors"]["H5179"]
-    reader, writer = await asyncio.wait_for(
-        asyncio.open_connection(h5179["host"], h5179["port"]),
-        timeout=2,
-    )
-    writer.write(b"status\n")
-    data = await asyncio.wait_for(reader.readline(), timeout=1)
-    lines = data.decode().strip().splitlines()
-    temp = hum = last = None
-    for line in lines:
-        name, temp, hum, __, last = line.split()
-        if name == "H5179":
-            break
+    path = pathlib.Path(__file__).parent / "../etc/schema.json"
 
-    if temp is None or hum is None or last is None:
-        raise ValueError("Did not get a measurement for H5179.")
-
-    temp = float(temp)
-    hum = float(hum)
-
-    last_seen = astropy.time.Time(last, format="isot")
-    delta = astropy.time.Time.now() - last_seen
-    if delta.datetime.seconds / 60 > 10:
-        raise RuntimeError("Lab metrology is over 10 minutes old.")
-
-    return temp, hum
+    return json.loads(open(path, "r").read())
