@@ -10,7 +10,8 @@ from __future__ import annotations
 
 import enum
 
-__all__ = ["ModType", "ControllerStatus"]
+
+__all__ = ["ModType", "ControllerStatus", "ArchonPower"]
 
 
 class ModType(enum.Enum):
@@ -43,9 +44,28 @@ class ControllerStatus(enum.Flag):
     READOUT_PENDING = 0x8
     READING = 0x10
     FETCHING = 0x20
-    ERROR = 0x40
+    FLUSHING = 0x40
+    ERROR = 0x80
+    POWERON = 0x100
+    POWEROFF = 0x200
+    POWERBAD = 0x400
+
+    ACTIVE = EXPOSING | READING | FETCHING | FLUSHING
+    ERRORED = ERROR | POWERBAD
 
     def get_flags(self):
         """Returns the the flags that compose the bit."""
 
-        return [bit for bit in ControllerStatus if bit & self]
+        skip = ["ACTIVE", "ERRORED"]
+
+        return [b for b in ControllerStatus if b & self and b.name not in skip]
+
+
+class ArchonPower(enum.Enum):
+
+    UNKNOWN = 0
+    NOT_CONFIGURED = 1
+    OFF = 2
+    INTERMEDIATE = 3
+    ON = 4
+    STANDBY = 5
